// MESSAGE BOOT support class

#pragma once

namespace mavlink {
namespace slugs {
namespace msg {

/**
 * @brief BOOT message
 *
 * The boot message indicates that a system is starting. The onboard software version allows to keep track of onboard soft/firmware revisions. This message allows the sensor and control MCUs to communicate version numbers on startup.
 */
struct BOOT : mavlink::Message {
    static constexpr msgid_t MSG_ID = 197;
    static constexpr size_t LENGTH = 4;
    static constexpr size_t MIN_LENGTH = 4;
    static constexpr uint8_t CRC_EXTRA = 39;
    static constexpr auto NAME = "BOOT";


    uint32_t version; /*<  The onboard software version */


    inline std::string get_name(void) const override
    {
            return NAME;
    }

    inline Info get_message_info(void) const override
    {
            return { MSG_ID, LENGTH, MIN_LENGTH, CRC_EXTRA };
    }

    inline std::string to_yaml(void) const override
    {
        std::stringstream ss;

        ss << NAME << ":" << std::endl;
        ss << "  version: " << version << std::endl;

        return ss.str();
    }

    inline void serialize(mavlink::MsgMap &map) const override
    {
        map.reset(MSG_ID, LENGTH);

        map << version;                       // offset: 0
    }

    inline void deserialize(mavlink::MsgMap &map) override
    {
        map >> version;                       // offset: 0
    }
};

} // namespace msg
} // namespace slugs
} // namespace mavlink
